@@ -30,23 +30,16 @@ class ClientException(BaseException):
 class AuthException(BaseException):
     pass
 
-API_HOST = 'https://nucleo.arcus.io/api/v1'
-
-def _request(path='', method='get', data=None, api_key=None, params={}):
-    data = utils.api_request(API_HOST, path, method=method, \
-        data=data, api_key=api_key, params={})
-    if data.status_code == 403:
-        raise AuthException('Unauthorized')
-    return data
+API_URL = 'https://nucleo.arcus.io/api/v1'
 
 class Client(object):
     """
     Arcus Client
 
     """
-    def __init__(self, username=None, password=None, host=API_HOST, \
+    def __init__(self, username=None, password=None, url=API_URL, \
         api_key=None):
-        self._host = host
+        self._api_url = url
         self._username = username
         self._password = password
         self._api_key = api_key
@@ -54,35 +47,32 @@ class Client(object):
         self._meta = {}
         if self._username and self._password:
             self._login()
+        else:
+            raise ClientException('You must specify a username and password')
 
-    @classmethod
-    def login(cls, username=None, password=None,
-        host='https://nucleo.arcus.io/api/v1'):
-        user_data = {'username': username, 'password': password}
-        resp = _request('/login', method='post', data=user_data)
+    def _request(self, path='', method='get', data=None, api_key=None, params={}):
+        data = utils.api_request(self._api_url, path, method=method, \
+            data=data, api_key=api_key, params={})
+        if data.status_code == 403:
+            raise AuthException('Unauthorized')
+        return data
+
+    def _login(self):
+        user_data = {'username': self._username, 'password': self._password}
+        resp = self._request('/login', method='post', data=user_data)
+        if resp.status_code == 200:
+            self._logged_in = True
+        else:
+            raise AuthException(data.get('error', 'Login fail'))
         data = {}
         try:
             data = json.loads(resp.content)
+            self._meta = data.get('meta', {})
+            self._api_key = data.get('meta', {}).get('api_key')
         except:
             pass
         return data
 
-        
-    def _login(self):
-        """
-        Logs in
-
-        :returns: User data as dict
-
-        """
-        data = self.login(self._username, self._password)
-        if data.get('status_code') == 200:
-            self._logged_in = True
-            self._meta = data.get('meta', {})
-            self._api_key = data.get('meta', {}).get('api_key')
-        else:
-            raise ClientException(data.get('error', 'Login fail'))
-
     def get_meta(self):
         """
         Returns meta user info
@@ -97,7 +87,7 @@ class Client(object):
         :returns: Applications as dict
 
         """
-        data = _request(path='/apps', method='get', api_key=self._api_key)
+        data = self._request(path='/apps', method='get', api_key=self._api_key)
         if data.status_code == 200:
             return data.json.get('apps')
         else:
@@ -110,7 +100,7 @@ class Client(object):
         :returns: Application data as dict
 
         """
-        data = _request('/apps/{0}'.format(name), method='get',
+        data = self._request('/apps/{0}'.format(name), method='get',
             api_key=self._api_key)
         if data.status_code == 200:
             return data.json.get('details')
@@ -124,7 +114,7 @@ class Client(object):
         :returns: Application statistics as dict
 
         """
-        data = _request('/apps/{0}/stats'.format(name), method='get',
+        data = self._request('/apps/{0}/stats'.format(name), method='get',
             api_key=self._api_key)
         if data.status_code == 200:
             return data.json.get('stats')
@@ -138,7 +128,7 @@ class Client(object):
         """
         node_name = socket.gethostname()
         # call puppet to register
-        data = _request('/nodes/register', method='post', \
+        data = self._request('/nodes/register', method='post', \
             data={'node_name': node_name}, api_key=self._api_key)
         if data.status_code == 200:
             data = json.loads(data.content)
